==> haskell-charset-0.3.7.1-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: charset
version: 0.3.7.1
id: charset-0.3.7.1-5zPyLnPN7X6E7FjxZev7pI
key: charset-0.3.7.1-5zPyLnPN7X6E7FjxZev7pI
license: BSD3
copyright: (c) Edward Kmett 2010-2012
maintainer: ekmett@gmail.com
stability: Experimental
homepage: http://github.com/ekmett/charset
synopsis: Fast unicode character sets based on complemented PATRICIA tries
description:
    Fast unicode character sets based on complemented PATRICIA tries
category: Data
author: Edward Kmett
exposed: True
exposed-modules:
    Data.CharSet Data.CharSet.Common Data.CharSet.Posix
    Data.CharSet.Posix.Ascii Data.CharSet.Posix.Unicode
    Data.CharSet.Unicode Data.CharSet.Unicode.Block
    Data.CharSet.Unicode.Category Data.CharSet.ByteSet
abi: cefd7f0764cef1663439eec2e10541d8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/charset-0.3.7.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/charset-0.3.7.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/charset-0.3.7.1
hs-libraries: HScharset-0.3.7.1-5zPyLnPN7X6E7FjxZev7pI
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    semigroups-0.18.1-ESRONlmV7qgKe0wL9ZoBKD
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html: /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-charset-0.3.7.1-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: charset
version: 0.3.7.1
id: charset-0.3.7.1-IfpzBcdrtrvG42nmA8DS1W
key: charset-0.3.7.1-IfpzBcdrtrvG42nmA8DS1W
license: BSD3
copyright: (c) Edward Kmett 2010-2012
maintainer: ekmett@gmail.com
stability: Experimental
homepage: http://github.com/ekmett/charset
synopsis: Fast unicode character sets based on complemented PATRICIA tries
description:
    Fast unicode character sets based on complemented PATRICIA tries
category: Data
author: Edward Kmett
exposed: True
exposed-modules:
    Data.CharSet Data.CharSet.Common Data.CharSet.Posix
    Data.CharSet.Posix.Ascii Data.CharSet.Posix.Unicode
    Data.CharSet.Unicode Data.CharSet.Unicode.Block
    Data.CharSet.Unicode.Category Data.CharSet.ByteSet
abi: e5c0e9a446651f6e4995637d9fc54f01
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/charset-0.3.7.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/charset-0.3.7.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/charset-0.3.7.1
hs-libraries: HScharset-0.3.7.1-IfpzBcdrtrvG42nmA8DS1W
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    semigroups-0.18.2-1UW5ZEaP4Cw95AdO3Ej2Ky
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html: /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
